server <- function(input, output) {
  output$tablef <-
    DT::renderDT({ DT::datatable(groupf, class = "display",options = list(
      pageLength = 6 ,
      order = list(6 , "desc"),
      scrollY = 300, scrollX = 400, scroller = TRUE
    )
    )
    }
    )

  output$issue_graph <- plotly::renderPlotly({
    p <- ggplot2::ggplot(groupf) +
      ggplot2::aes(x = reorder(name,-open_issues_count), y = open_issues_count) +
      ggplot2::geom_col(fill = "#000091") +
      gouvdown::theme_gouv() +
      ggplot2::theme(legend.position = "none",
                     axis.title.x = ggplot2::element_blank(),
                     axis.text.x = ggplot2::element_blank(),
                     axis.ticks.x = ggplot2::element_blank(),
                     axis.title.y = ggplot2::element_blank())
    plotly::ggplotly(p)
  })

  # filtre les issues pour seulement garder ls variable interresante et celles encore ouverte pourl'exploration des données
  groupid <- shiny::reactive({gitlabr::gl_list_issues(project = input$ID1) %>%
      dplyr::select(iid ,
                    title,
                    description ,
                    state ,
                    created_at ,
                    updated_at ,
                    type,
                    labels,
                    user_notes_count) })
  groupidf <- shiny::reactive({groupid() %>% dplyr::filter( state == "opened")})

  nfermer <- shiny::reactive({nrow(groupid() %>% dplyr::filter( state == "closed"))})
  output$issue_nbr <- shiny::renderText({paste(nfermer(),"issues ont été fermées sur le projet", input$ID1)})

  output$issue <-
    DT::renderDT({
      DT::datatable(groupidf(),
                    class = "display",
                    options = list(pageLength = 6 ,
                                   order = list(6 , "desc"),
                                   scrollY = 600, scrollX = 400, scroller = TRUE))
    })
  dateinf <- shiny::reactive({
    tail(groupid()$created_at, 1)
  })
  shiny::observeEvent(input$daterange1, {
    print(dateinf())
  })
  output$dateinferieur <- shiny::renderText({dateinf()})


  output$activity <-
    DT::renderDT({
      DT::datatable(
        final_table,
        class = "display",
        options = list(
          pageLength = 20 ,
          order = list(7 , "desc"),
          scrollY = 2500,
          scrollX = 800,
          scroller = TRUE,
          autoWidth = TRUE
        )
      )
    })

  filteredData <- shiny::reactive({
    shiny::req(input$daterange)
    data_chronol %>%
      dplyr::filter(temps >= as.Date(input$daterange[[1]]) & temps <= as.Date(input$daterange[[2]]))
  })

  output$filteredPlot <- plotly::renderPlotly({

    p <- ggplot2::ggplot(filteredData(), ggplot2::aes(x = temps, y = as.factor(name))) +
      ggplot2::geom_jitter(ggplot2::aes(color = type, text = paste(temps, info, sep = "\n")), size = 3, alpha = 0.5,
                           height = 0, width = 0.75) +
      ggplot2::labs(shape = "Type", color = "Type", x = "") +
      ggplot2::scale_x_datetime(date_labels = "%d %b", timezone = "Europe/Paris") +
      gouvdown::theme_gouv() +
      ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 0, hjust = 1),
                     axis.title.y = ggplot2::element_blank()) +
      gouvdown::scale_color_gouv_discrete(palette = "pal_gouv_qual1")

    plotly::ggplotly(p, tooltip = "text")
  })

}
